@@ -618,7 +618,7 @@ set_key (GtkWidget *widget, gpointer ptr)
  */
 {
    key_widget_t	*kw   = (key_widget_t *) ptr;
-   char		*text = gtk_entry_get_text (GTK_ENTRY (kw->keyname));
+   const char	*text = gtk_entry_get_text (GTK_ENTRY (kw->keyname));
    unsigned 	 n;
    
    if (strcaseeq (text, "None"))
