@@ -17,7 +17,7 @@
 #define _KEYS_H
 
 #include <gtk/gtk.h>
-#include <proplist.h>
+#include "proplist_t.h"
 
 typedef struct key_widget
 {
