@@ -30,7 +30,7 @@
 #ifndef _LOAD_H
 #define _LOAD_H
 
-#include <proplist.h>
+#include "proplist_t.h"
 
 proplist_t 
 ReadProplistFromFile (const char *file);
