@@ -37,7 +37,7 @@
 #	include <strings.h>
 #endif /* not HAVE_STRING_H */
 #include <gtk/gtk.h>
-#include <proplist.h>
+#include "proplist_t.h"
 
 typedef unsigned bool_t;
 
@@ -63,11 +63,13 @@ char *
 expand_tilde (const char *name);
 char *
 preview_name (const char *name);
-proplist_t *
+proplist_t
 read_proplist (const char *filename);
 char *
 get_temporary_file_name (void);
 char *
+make_temporary_directory (void);
+char *
 protect_quotes (char *string);
 bool_t
 copy_file (const char *dst, const char *src);
