@@ -31,7 +31,7 @@
 #define _PATH_H
 
 void
-path_dialog (GtkWidget *page, proplist_t *key, proplist_t *array,
-	     GtkTooltips *tooltips, proplist_t *info);
+path_dialog (GtkWidget *page, proplist_t key, proplist_t array,
+	     GtkTooltips *tooltips, proplist_t info);
 
 #endif /* not _PATH_H */
