@@ -112,10 +112,10 @@ gboolean
 make_color(const gchar *spec, GdkColor *color)
 {
   gboolean result;
-  gchar * newspec = spec;
+  gchar * newspec = g_strdup (spec);
 
   if (strncmp(spec, "rgb:", 4) == 0) {
-    char * red_posn = spec + 4, * green_posn, * blue_posn;
+    const char * red_posn = spec + 4, * green_posn, * blue_posn;
     int red_len, green_len, blue_len;
     
     green_posn = strchr(red_posn, '/');
