@@ -39,6 +39,8 @@ typedef enum gtype {HGRADIENT, VGRADIENT, DGRADIENT} gtype_e;
 #include <wraster.h>
 #include "proplist_t.h"
 
+gboolean
+make_color(const gchar *spec, GdkColor *color);
 GtkWidget *
 make_image (const char *filename, int width, int height, GtkWidget *preview);
 GtkWidget *
